@@ -316,7 +316,7 @@ multicov.smooth <- function(object, type=c("analytical","empirical","simulated")
 
 #' @importFrom stats logLik
 #' @export
-logLik.smooth <- function(object,...){
+logLik.smooth <- function(object, ...){
     if(is.null(object$logLik)){
         warning("The likelihood of this model is unavailable. Hint: did you use combinations?");
         return(NULL);
@@ -326,7 +326,7 @@ logLik.smooth <- function(object,...){
     }
 }
 #' @export
-logLik.smooth.sim <- function(object,...){
+logLik.smooth.sim <- function(object, ...){
     obs <- nobs(object);
     return(structure(object$logLik,nobs=obs,df=0,class="logLik"));
 }
@@ -357,11 +357,10 @@ nparam.smooth <- function(object, ...){
         return(NULL);
     }
     else{
-        return(object$nParam[1,4]);
+        return(object$nParam[1,ncol(object$nParam)]);
     }
 }
 
-
 #' Prediction Likelihood Score
 #'
 #' Function estimates Prediction Likelihood Score for the provided model
@@ -724,7 +723,7 @@ fitted.smooth.forecast <- function(object, ...){
 #' plot(forecast(ourModel,h=10,interval=TRUE))
 #'
 #' @rdname forecast.smooth
-#' @importFrom greybox forecast
+#' @importFrom generics forecast
 #' @export
 forecast.smooth <- function(object, h=10,
                             interval=c("parametric","semiparametric","nonparametric","none"),
@@ -1864,60 +1863,49 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
     }
 
     # Do plots
-    if(any(which==1)){
-        plot1(x, ...);
-    }
-
-    if(any(which==2)){
-        plot2(x, ...);
-    }
-
-    if(any(which==3)){
-        plot2(x, "rstudent", ...);
-    }
-
-    if(any(which==4)){
-        plot3(x, ...);
-    }
-
-    if(any(which==5)){
-        plot3(x, type="squared", ...);
-    }
-
-    if(any(which==6)){
-        plot4(x, ...);
-    }
-
-    if(any(which==7)){
-        plot5(x, ...);
-    }
-
-    if(any(which==8)){
-        plot6(x, ...);
-    }
-
-    if(any(which==9)){
-        plot6(x, "rstudent", ...);
-    }
-
-    if(any(which==10)){
-        plot7(x, type="acf", ...);
-    }
-
-    if(any(which==11)){
-        plot7(x, type="pacf", ...);
-    }
-
-    if(any(which==12)){
-        plot8(x, ...);
-    }
-
-    if(any(which==13)){
-        plot9(x, ...);
-    }
-
-    if(any(which==14)){
-        plot9(x, type="squared", ...);
+    for(i in which){
+        if(any(i==1)){
+            plot1(x, ...);
+        }
+        else if(any(i==2)){
+            plot2(x, ...);
+        }
+        else if(any(i==3)){
+            plot2(x, "rstudent", ...);
+        }
+        else if(any(i==4)){
+            plot3(x, ...);
+        }
+        else if(any(i==5)){
+            plot3(x, type="squared", ...);
+        }
+        else if(any(i==6)){
+            plot4(x, ...);
+        }
+        else if(any(i==7)){
+            plot5(x, ...);
+        }
+        else if(any(i==8)){
+            plot6(x, ...);
+        }
+        else if(any(i==9)){
+            plot6(x, "rstudent", ...);
+        }
+        else if(any(i==10)){
+            plot7(x, type="acf", ...);
+        }
+        else if(any(i==11)){
+            plot7(x, type="pacf", ...);
+        }
+        else if(any(i==12)){
+            plot8(x, ...);
+        }
+        else if(any(i==13)){
+            plot9(x, ...);
+        }
+        else if(any(i==14)){
+            plot9(x, type="squared", ...);
+        }
     }
 }
 
